@@ -1,5 +1,6 @@
-"""$URL: svn+ssh://svn.mems-exchange.org/repos/trunk/durus/logger.py $
-$Id: logger.py 24062 2004-04-27 19:18:06Z dbinger $
+"""
+$URL: svn+ssh://svn.mems-exchange.org/repos/trunk/durus/logger.py $
+$Id: logger.py 29018 2006-10-31 21:03:13Z rmasse $
 """
 
 import sys
